@@ -23,3 +23,10 @@ class Tool(object):
         if at_alls is None:
             at_alls = []
         send_robot_msg_util(msg, 'qyWechat', qy_wechat_token=self.qy_wechat_token, at_alls=at_alls)
+
+    @staticmethod
+    def logger(msg):
+        """
+        记录日志
+        """
+        logger_util(msg)
\ No newline at end of file
